<template>
    <div class="loan-info-box">
        <x-header slot="header"
                  style="width:100%;height:46px;background-color: #ec6758"
                  title="公司信息"
                  :left-options="{backText: '', preventGoBack:true}"
                  @on-click-back="goBackPage"
        ></x-header>
        <flow class="progressState">
            <flow-state state="1" title="填写资料" class="currentStep porcolor"></flow-state>
            <flow-line is-done></flow-line>
            <flow-state state="2" title="绑定银行卡" class="currentStep porcolor"></flow-state>
            <flow-line is-done></flow-line>
            <flow-state state="3" title="照片上传" class="currentStep porcolor"></flow-state>
            <flow-line is-done></flow-line>
            <flow-state state="4" title="三方授权" class="currentStep porcolor"></flow-state>
            <flow-line is-done></flow-line>
            <flow-state state="5" title="提交申请" class="currentStep porcolor"></flow-state>
        </flow>
        <group class="personInfo" text-align="right">
            <x-input
                title="公司名称"
                placeholder="请输入公司名称"
                v-model.trim="ComyInfo.comyName"

            ></x-input>
            <x-input
                title="公司详细地址"
                placeholder="请输入公司详细地址"
                v-model.trim="ComyInfo.comyAddr"
            ></x-input>
            <selector title="所属行业"
                      :options="industryList"
                      placeholder="请选择"
                      v-model="ComyInfo.industry"
            ></selector>
            <selector title="职位/职称"
                      :options="jobRankList"
                      placeholder="请选择"
                      v-model="ComyInfo.jobRank"
            ></selector>
        </group>
        <div style="height: 20px"></div>
        <box gap="0 15px">
            <x-button type="primary" @click.native="gohome">取消修改</x-button>
            <x-button type="primary" @click.native="goback">确认修改</x-button>
        </box>
        <div style="height: 20px"></div>
    </div>
</template>

<script>
    import {
        Flow,
        FlowState,
        FlowLine,
        XHeader,
        Group,
        GroupTitle,
        Cell,
        XInput,
        Selector,
        XButton,
        Box,
        Actionsheet
    } from 'vux';

    import FSpace from '../../../components/common/FSpace.vue';
    import validate from '../../../tool/validator';
    import SysApi from '../../../api/api'
    import statusCodeManage from '../../../api/statusCodeManage'

    export default {
        name: 'companyModification',
        data() {
            return {
                ComyInfo: {
                    comyName: '',
                    comyAddr: '',
                    industry: [],
                    jobRank: [],
                }, // 初始化的用户信息
                isLastStep: false, // 是否是最后一步
                activePageItem: 0, // 激活当前页
                pageList: [], // 一共有几页

                jobRankList: [],
                industryList: []
            };
        },
        methods: {
            //初始化公司信息
            initComyInfo() {
                let _this = this;
                let prodId = {
                    prodId: this.$route.query.prodId,
                };
                SysApi.initComy(prodId).then(
                    res => {
                        _this.ComyInfo.comyName = res.body.comyName;
                        _this.ComyInfo.comyAddr = res.body.comyAddr;
                        _this.ComyInfo.industry = res.body.industry;
                        _this.ComyInfo.jobRank = res.body.jobRank;
                        console.log(res);
                        _this.jobRankList = this.getOptionsList(res.body.jobRankList);
                        _this.industryList = this.getOptionsList(res.body.industryList);
                    }, error => {
                        statusCodeManage.showTipOfStatusCode(error)
                    }
                )
            },
            //上一步跳转
            gohome() {
                this.$router.push({
                    path: '/bnd/credit/infoOk', query: {prodId: this.$route.query.prodId}
                });
            },
            //下一步的表单验证及提交
            goback() {
                if (validate.checkValEmpty(this.ComyInfo.comyName)) {
                    this.validateTip('请输入公司名称');
                    return false;
                }
                if (validate.checkValEmpty(this.ComyInfo.comyAddr)) {
                    this.validateTip('请输入公司详细地址');
                    return false;
                }
                if (validate.checkValEmpty(this.ComyInfo.industry)) {
                    this.validateTip('请选择所属行业');
                    return false;
                }
                if (validate.checkValEmpty(this.ComyInfo.jobRank)) {
                    this.validateTip('请选择职位/职称');
                    return false;
                }
                let _this = this;
                let ComyInfo = {
                    //pordId通过路由传递
                    prodId: this.$route.query.prodId,
                    comyName: this.ComyInfo.comyName,
                    comyAddr: this.ComyInfo.comyAddr,
                    industry: this.ComyInfo.industry,
                    jobRank: this.ComyInfo.jobRank,
                };
                SysApi.saveComyInfo(ComyInfo).then(
                    res => {
                        this.$router.push({
                            path: '/bnd/credit/infoOk', query: {prodId: _this.$route.query.prodId}
                        });
                    }, error => {
                        statusCodeManage.showTipOfStatusCode(error)
                    }
                )
            },

            // 弹窗
            validateTip(errorMsg) {
                return this.$vux.toast.show({
                    width: 'auto',
                    type: 'text',
                    text: errorMsg,
                    time: 2000,
                    position: 'middle'
                });
            },
            // 得到选项列表统一的方法
            getOptionsList(optionList) {
                let tmpList = [];
                if (optionList instanceof Array) {
                    optionList.forEach(function (item) {
                        tmpList.push({
                            key: item.code,
                            value: item.name
                        });
                    });
                }
                return tmpList;
            },
            //返回上一页
            goBackPage() {
                // 如果是第一步的话，那么返回到上一个页面
                if (this.activePageItem <= 1) {
                    this.$router.back();
                    // 不是的话，那么显示上一步
                } else {
                    this.activePageItem--;
                    this.isLastStep = this.pageList.length === this.activePageItem;
                }
            },
        },
        activated: function () {
            this.initComyInfo();
        },
        components: {
            Group,
            GroupTitle,
            Cell,
            XInput,
            Selector,
            XHeader,
            XButton,
            Box,
            Flow,
            FlowState,
            FlowLine,
            Actionsheet,
            FSpace
        }
    };
</script>

<style lang="less">
    @import "../../../style/mixin.less";

    .loan-info-box {
        background-color: @color-background-default;
        .vux-header {
            .color-linear-gradient(@color-primary-light, @color-primary, 90deg);
            .vux-header-left {
                .left-arrow:before {
                    border: solid 1px @color-white;
                    border-width: 2px 0 0 2px;
                }
            }
        }
        .progressState div p {
            font-size: @font-size-tiny;
        }
        .weui-wepay-flow__state {
            width: 16px;
            height: 16px;
            top: -1px;
            padding-top: 1px;
        }
        .currentStep .weui-wepay-flow__state {
            width: 16px;
            height: 16px;
            padding-top: 1px;
            border: 1px solid @color-primary;
            color: @color-primary;
            border-radius: 50%;
            background-color: @color-white;
        }
        .weui-input {
            height: 28px;
            line-height: 28px;
        }
        .weui-wepay-flow, .weui-wepay-flow-auto {
            padding: 10px 40px 30px;
            background: @color-white;
        }
        .weui-wepay-flow__li_done .weui-wepay-flow__state,
        .weui-wepay-flow__process {
            background-color: @color-primary;
        }
    }

    .weui-wepay-flow {
        background-color: @color-white;
    }

    .left-arrow:before {
        border-color: @color-white;
    }

    .weui-cells__title {
        margin: 0 !important;
        font-size: 16PX !important;
    }

    .weui-input, .weui-cell__bd {
        font-size: @font-size-base;
    }

    .weui-label {
        font-size: @font-size-base;
    }

    .personInfo ::-webkit-input-placeholder { /* WebKit browsers */
        color: #bfbfbf;
    }

    .personInfo :-moz-placeholder { /* Mozilla Firefox 4 to 18 */
        color: #bfbfbf;
    }

    .personInfo ::-moz-placeholder { /* Mozilla Firefox 19+ */
        color: #bfbfbf;
    }

    .personInfo :-ms-input-placeholder { /* Internet Explorer 10+ */
        color: #bfbfbf;
    }

    .header-space {
        height: 46px;
    }

    .loan-info-box .weui-cell_select .weui-select {
        padding-right: 2.5rem;
        direction: rtl;
    }

    .loan-info-box .weui-input {
        text-align: right;
        font-size: @font-size-medium;
    }

    .loan-info-box .weui-btn_primary {
        .color-linear-gradient(@color-primary-light, @color-primary, 90deg);
    }

    .loan-info-box .weui-btn_primary:not(.weui-btn_disabled):active {
        color: rgba(255, 255, 255, 0.6);
        background-color: rgb(241, 95, 79);;
    }

    /*------------------------------*/
    .vux-no-group-title {
        margin-top: 0.77rem !important;
    }

    .loan-info-box .currentStep .weui-wepay-flow__state {
        background-color: @color-primary;
        color: @color-white !important;
        line-height: 1rem;
    }

    .weui-wepay-flow__li.weui-wepay-flow__li .weui-wepay-flow__state {
        width: 1.33333rem;
        height: 1.33333rem;
        border-radius: 1.58333rem;
        color: @color-text-third;
        line-height: 1.33333rem;
    }

    .porcolor p {
        color: @color-primary;
    }

    .loan-info-box .weui-wepay-flow, .loan-info-box .weui-wepay-flow-auto {
        padding: 0.83333rem 2.33333rem 2.5rem;
    }

    select {
        font-size: @font-size-medium !important;
    }

    .weui-btn:after {
        border: none !important;
    }

    .weui-btn {
        font-size: @font-size-primary !important;
    }
</style>
